@@ -8,7 +8,7 @@ use Data::Printer;
 use MetaCPAN::Client;
 
 my $author =
-    MetaCPAN::Client->new->author('XSAWYERX');
+    MetaCPAN::Client->new( version => 'v1' )->author('XSAWYERX');
 
 my %output = (
     NAME    => $author->name,
@@ -16,7 +16,8 @@ my %output = (
     COUNTRY => $author->country,
     CITY    => $author->city,
     PROFILE => $author->profile,
+    LINKS   => $author->links,
+    RELEASE_COUNTS => $author->release_count,
 );
 
 p %output;
-
